@@ -3,7 +3,7 @@
 from aind_data_schema.imaging import instrument
 
 inst = instrument.Instrument(
-    instrument_id="SmartSPIM02",
+    instrument_id="SmartSPIM2-1",
     type="smartSPIM",
     manufacturer="LifeCanvas",
     location="440 Westlake",
